@@ -5,14 +5,13 @@ from itertools import chain
 
 import astropy.units as u
 from astropy.units import Quantity
-from astropy.table import Table
+from astropy.table import QTable
 from astropy.io import fits
 from astropy.nddata import StdDevUncertainty, VarianceUncertainty, InverseVariance
-from astropy.time import Time
-from astropy.wcs import WCS
 from gwcs.wcstools import grid_from_bounding_box
+import numpy as np
 
-from ...spectra import Spectrum1D, SpectrumList
+from ...spectra import Spectrum, SpectrumList
 from ..registers import data_loader
 from ..parsing_utils import read_fileobj_or_hdulist
 
@@ -46,7 +45,10 @@ def _identify_spec1d_fits(origin, extname, *args, **kwargs):
     """ Generic spec 1d identifier function """
     is_jwst = _identify_jwst_fits(*args)
     with read_fileobj_or_hdulist(*args, memmap=False, **kwargs) as hdulist:
-        return (is_jwst and extname in hdulist and (extname, 2) not in hdulist)
+        table = QTable(hdulist[extname].data)
+        spectrum_per_row = table[0]['WAVELENGTH'].shape != ()
+        return (is_jwst and extname in hdulist and (extname, 2) not in hdulist and
+                not spectrum_per_row)
 
 
 def _identify_spec1d_multi_fits(origin, extname, *args, **kwargs):
@@ -55,7 +57,10 @@ def _identify_spec1d_multi_fits(origin, extname, *args, **kwargs):
     """
     is_jwst = _identify_jwst_fits(*args)
     with read_fileobj_or_hdulist(*args, memmap=False, **kwargs) as hdulist:
-        return is_jwst and (extname, 2) in hdulist
+        return is_jwst and ((extname, 2) in hdulist or
+                            (extname in hdulist and
+                             hdulist[extname].header['XTENSION'] == 'BINTABLE' and
+                             hdulist[extname].header['NAXIS'] == 2))
 
 
 def identify_jwst_c1d_fits(origin, *args, **kwargs):
@@ -129,7 +134,7 @@ def _identify_jwst_fits(*args):
 
 
 @data_loader(
-    "JWST c1d", identifier=identify_jwst_c1d_fits, dtype=Spectrum1D,
+    "JWST c1d", identifier=identify_jwst_c1d_fits, dtype=Spectrum,
     extensions=['fits'], priority=10,
 )
 def jwst_c1d_single_loader(file_obj, **kwargs):
@@ -143,7 +148,7 @@ def jwst_c1d_single_loader(file_obj, **kwargs):
 
     Returns
     -------
-    Spectrum1D
+    Spectrum
         The spectrum contained in the file.
     """
     spectrum_list = _jwst_spec1d_loader(file_obj, extname='COMBINE1D', **kwargs)
@@ -177,7 +182,7 @@ def jwst_c1d_multi_loader(file_obj, **kwargs):
 
 
 @data_loader(
-    "JWST x1d", identifier=identify_jwst_x1d_fits, dtype=Spectrum1D,
+    "JWST x1d", identifier=identify_jwst_x1d_fits, dtype=Spectrum,
     extensions=['fits'], priority=10
 )
 def jwst_x1d_single_loader(file_obj, **kwargs):
@@ -191,7 +196,7 @@ def jwst_x1d_single_loader(file_obj, **kwargs):
 
     Returns
     -------
-    Spectrum1D
+    Spectrum
         The spectrum contained in the file.
     """
     spectrum_list = _jwst_spec1d_loader(file_obj, extname='EXTRACT1D', **kwargs)
@@ -286,7 +291,69 @@ def jwst_x1d_miri_mrs_loader(input, missing="raise", **kwargs):
     return SpectrumList(chain.from_iterable(spectra))
 
 
-def _jwst_spec1d_loader(file_obj, extname='EXTRACT1D', **kwargs):
+def _jwst_spectrum_from_table(data, hdu_header, primary_header, flux_col=None, srctype=None):
+    # Create a Spectrum from either a table or a single row of a table
+
+    wavelength = Quantity(data['WAVELENGTH'])
+
+    # Determine if FLUX or SURF_BRIGHT column should be returned
+    # based on whether it is point or extended source. This will be overridden
+    # if flux_col is input by the user.
+    #
+    # SRCTYPE used to be in primary header, but was moved around. As
+    # per most recent pipeline definition, it should be in the
+    # EXTRACT1D extension. For WFSS files, it will be a table column and thus
+    # input to this function when a row is input as data.
+    #
+    # SRCTYPE should either be POINT or EXTENDED.  In some cases, it is UNKNOWN
+    # or missing.  If that's the case, default to using POINT as the SRCTYPE.
+    # Error out only when SRCTYPE is a bad value.
+    if "srctype" in hdu_header:
+        srctype = hdu_header.get("srctype", None)
+
+    # checking if SRCTPYE is missing or UNKNOWN
+    if not srctype or srctype == 'UNKNOWN':
+        warnings.warn('SRCTYPE is missing or UNKNOWN in JWST x1d loader. '
+                        'Defaulting to srctype="POINT".')
+        srctype = 'POINT'
+
+    # If flux column was not set manually, check source type
+    if flux_col is None:
+        if srctype == "POINT":
+            flux_col = "FLUX"
+        elif srctype == "EXTENDED":
+            flux_col = "SURF_BRIGHT"
+        else:
+            raise RuntimeError(f"Keyword SRCTYPE is {srctype}.  It should "
+                               "be 'POINT' or 'EXTENDED'. Can't decide between `flux` and "
+                               "`surf_bright` columns.")
+
+    if flux_col.lower() == "flux":
+        flux = Quantity(data["FLUX"])
+        if 'ERROR' in data.colnames:
+            uncertainty = StdDevUncertainty(data["ERROR"])
+        elif 'FLUX_ERROR' in data.colnames:
+            uncertainty = StdDevUncertainty(data["FLUX_ERROR"])
+        else:
+            uncertainty = None
+    elif flux_col.lower() == "surf_bright":
+        flux = Quantity(data["SURF_BRIGHT"])
+        uncertainty = StdDevUncertainty(data["SB_ERROR"])
+    else:
+        flux = Quantity(data[flux_col])
+
+    # Merge primary and slit headers and dump into meta
+    header = primary_header.copy()
+    header.extend(hdu_header, strip=True, update=True)
+    meta = {'header': header}
+    if 'SOURCE_ID' in data.colnames:
+        meta['source_id'] = data['SOURCE_ID']
+
+    return Spectrum(flux=flux, spectral_axis=wavelength,
+                        uncertainty=uncertainty, meta=meta)
+
+
+def _jwst_spec1d_loader(file_obj, extname='EXTRACT1D', flux_col=None, **kwargs):
     """Implementation of loader for JWST x1d 1-D spectral data in FITS format
 
     Parameters
@@ -296,6 +363,9 @@ def _jwst_spec1d_loader(file_obj, extname='EXTRACT1D', **kwargs):
           or HDUList (as resulting from astropy.io.fits.open()).
     extname: str
         The name of the science extension. Either "COMBINE1D" or "EXTRACT1D".  By default "EXTRACT1D".
+    flux_col: str
+        Optional keyword to force the reader to use the specified column as the flux,
+        rather than defaulting based on whether the source type is "EXTENDED" or "POINT".
 
     Returns
     -------
@@ -317,67 +387,36 @@ def _jwst_spec1d_loader(file_obj, extname='EXTRACT1D', **kwargs):
             if hdu.name != extname:
                 continue
 
+            header = hdu.header
+
             # Correct some known bad unit strings before reading the table
             bad_units = {"(MJy/sr)^2": "MJy2 sr-2"}
             for c in hdu.columns:
                 if c.unit in bad_units:
                     c.unit = bad_units[c.unit]
 
-            data = Table.read(hdu)
+            data = QTable.read(hdu)
 
-            wavelength = Quantity(data["WAVELENGTH"])
-
-            # Determine if FLUX or SURF_BRIGHT column should be returned
-            # based on whether it is point or extended source.
-            #
-            # SRCTYPE used to be in primary header, but was moved around. As
-            # per most recent pipeline definition, it should be in the
-            # EXTRACT1D extension.
-            #
-            # SRCTYPE should either be POINT or EXTENDED.  In some cases, it is UNKNOWN
-            # or missing.  If that's the case, default to using POINT as the SRCTYPE.
-            # Error out only when SRCTYPE is a bad value.
-            srctype = None
-            if "srctype" in hdu.header:
-                srctype = hdu.header.get("srctype", None)
-
-            # checking if SRCTPYE is missing or UNKNOWN
-            if not srctype or srctype == 'UNKNOWN':
-                warnings.warn('SRCTYPE is missing or UNKNOWN in JWST x1d loader. '
-                              'Defaulting to srctype="POINT".')
-                srctype = 'POINT'
-
-            if srctype == "POINT":
-                flux = Quantity(data["FLUX"])
-                if 'ERROR' in data.colnames:
-                    uncertainty = StdDevUncertainty(data["ERROR"])
-                elif 'FLUX_ERROR' in data.colnames:
-                    uncertainty = StdDevUncertainty(data["FLUX_ERROR"])
-                else:
-                    uncertainty = None
-            elif srctype == "EXTENDED":
-                flux = Quantity(data["SURF_BRIGHT"])
-                uncertainty = StdDevUncertainty(data["SB_ERROR"])
+            if data[0]['WAVELENGTH'].shape != ():
+                # In this case we have multiple spectra packed into a single extension, one target
+                # per row of the table
+                for row in data:
+                    if hasattr(row['WAVELENGTH'], 'mask') and np.all(row['WAVELENGTH'].mask):
+                        # If everything is masked out we don't bother to read it in at all
+                        continue
+                    srctype = row['SOURCE_TYPE']
+                    spec = _jwst_spectrum_from_table(row, header, primary_header, flux_col, srctype)
+                    spectra.append(spec)
             else:
-                raise RuntimeError(f"Keyword SRCTYPE is {srctype}.  It should "
-                                   "be 'POINT' or 'EXTENDED'. Can't decide between `flux` and "
-                                   "`surf_bright` columns.")
-
-            # Merge primary and slit headers and dump into meta
-            slit_header = hdu.header
-            header = primary_header.copy()
-            header.extend(slit_header, strip=True, update=True)
-            meta = {'header': header}
-
-            spec = Spectrum1D(flux=flux, spectral_axis=wavelength,
-                              uncertainty=uncertainty, meta=meta)
-            spectra.append(spec)
+                # Otherwise the whole table is defining a single spectrum
+                spec = _jwst_spectrum_from_table(data, header, primary_header, flux_col)
+                spectra.append(spec)
 
     return SpectrumList(spectra)
 
 
 @data_loader(
-    "JWST s2d", identifier=identify_jwst_s2d_fits, dtype=Spectrum1D,
+    "JWST s2d", identifier=identify_jwst_s2d_fits, dtype=Spectrum,
     extensions=['fits'], priority=10,
 )
 def jwst_s2d_single_loader(filename, **kwargs):
@@ -391,7 +430,7 @@ def jwst_s2d_single_loader(filename, **kwargs):
 
     Returns
     -------
-    Spectrum1D
+    Spectrum
         The spectrum contained in the file.
     """
     spectrum_list = _jwst_s2d_loader(filename, **kwargs)
@@ -491,17 +530,17 @@ def _jwst_s2d_loader(filename, **kwargs):
                 # Make sure all rows are the same
                 if not (lam == wavelength_array).all():
                     raise RuntimeError("This 2D or 3D spectrum is not rectified "
-                                       "and cannot be loaded into a Spectrum1D object.")
+                                       "and cannot be loaded into a Spectrum object.")
             elif dispaxis == 2:
                 flux_array = hdu.data.T
                 wavelength_array = lam[:, 0]
                 # Make sure all columns are the same
                 if not (lam.T == lam[None, :, 0]).all():
                     raise RuntimeError("This 2D or 3D spectrum is not rectified "
-                                       "and cannot be loaded into a Spectrum1D object.")
+                                       "and cannot be loaded into a Spectrum object.")
             else:
                 raise RuntimeError("This 2D spectrum has an unknown dispaxis "
-                                   "and cannot be loaded into a Spectrum1D object.")
+                                   "and cannot be loaded into a Spectrum object.")
 
             flux = Quantity(flux_array, unit=flux_unit)
             wavelength = Quantity(wavelength_array, unit=lam_unit)
@@ -512,14 +551,14 @@ def _jwst_s2d_loader(filename, **kwargs):
             header.extend(slit_header, strip=True, update=True)
             meta = {'header': header}
 
-            spec = Spectrum1D(flux=flux, spectral_axis=wavelength, meta=meta)
+            spec = Spectrum(flux=flux, spectral_axis=wavelength, meta=meta)
             spectra.append(spec)
 
     return SpectrumList(spectra)
 
 
 @data_loader(
-    "JWST s3d", identifier=identify_jwst_s3d_fits, dtype=Spectrum1D,
+    "JWST s3d", identifier=identify_jwst_s3d_fits, dtype=Spectrum,
     extensions=['fits'], priority=10,
 )
 def jwst_s3d_single_loader(filename, **kwargs):
@@ -533,7 +572,7 @@ def jwst_s3d_single_loader(filename, **kwargs):
 
     Returns
     -------
-    Spectrum1D
+    Spectrum
         The spectrum contained in the file.
     """
     spectrum_list = _jwst_s3d_loader(filename, **kwargs)
@@ -579,38 +618,9 @@ def _jwst_s3d_loader(filename, **kwargs):
             except (ValueError, KeyError):
                 flux_unit = None
 
-            # The spectral axis is first.  We need it last
-            flux_array = hdu.data.T
+            flux_array = hdu.data
             flux = Quantity(flux_array, unit=flux_unit)
 
-            # Get the wavelength array from the GWCS object which returns a
-            # tuple of (RA, Dec, lambda).
-            # Since the spatial and spectral axes are orthogonal in s3d data,
-            # it is much faster to compute a slice down the spectral axis.
-            grid = grid_from_bounding_box(wcs.bounding_box)[:, :, 0, 0]
-            _, _, wavelength_array = wcs(*grid)
-            _, _, wavelength_unit = wcs.output_frame.unit
-
-            wavelength = Quantity(wavelength_array, unit=wavelength_unit)
-
-            # The GWCS is currently broken for some IFUs, here we work around that
-            wcs = None
-            if wavelength.shape[0] != flux.shape[-1]:
-                # Need MJD-OBS for this workaround
-                if 'MJD-OBS' not in hdu.header:
-                    for key in ('MJD-BEG', 'DATE-OBS'):  # Possible alternatives
-                        if key in hdu.header:
-                            if key.startswith('MJD'):
-                                hdu.header['MJD-OBS'] = hdu.header[key]
-                                break
-                            else:
-                                t = Time(hdu.header[key])
-                                hdu.header['MJD-OBS'] = t.mjd
-                                break
-                wcs = WCS(hdu.header)
-                # Swap to match the flux transpose
-                wcs = wcs.swapaxes(-1, 0)
-
             # Merge primary and slit headers and dump into meta
             slit_header = hdu.header
             header = primary_header.copy()
@@ -621,7 +631,7 @@ def _jwst_s3d_loader(filename, **kwargs):
             ext_name = primary_header.get("ERREXT", "ERR")
             err_type = hdulist[ext_name].header.get("ERRTYPE", 'ERR')
             err_unit = hdulist[ext_name].header.get("BUNIT", None)
-            err_array = hdulist[ext_name].data.T
+            err_array = hdulist[ext_name].data
 
             # ERRTYPE can be one of "ERR", "IERR", "VAR", "IVAR"
             # but mostly ERR for JWST cubes
@@ -639,13 +649,10 @@ def _jwst_s3d_loader(filename, **kwargs):
 
             # get mask information
             mask_name = primary_header.get("MASKEXT", "DQ")
-            mask = hdulist[mask_name].data.T
+            mask = hdulist[mask_name].data
+
+            spec = Spectrum(flux=flux, wcs=wcs, meta=meta, uncertainty=err, mask=mask, spectral_axis_index=0)
 
-            if wcs is not None:
-                spec = Spectrum1D(flux=flux, wcs=wcs, meta=meta, uncertainty=err, mask=mask)
-            else:
-                spec = Spectrum1D(flux=flux, spectral_axis=wavelength, meta=meta,
-                                  uncertainty=err, mask=mask)
             spectra.append(spec)
 
     return SpectrumList(spectra)
