@@ -4,10 +4,9 @@ import pytest
 from astropy import time
 from astropy.coordinates import (SkyCoord, EarthLocation, ICRS, Galactic,
                                  SpectralCoord, FK5)
-from astropy.utils.exceptions import AstropyDeprecationWarning
 
 from ..spectra.spectral_axis import SpectralAxis
-from ..spectra.spectrum1d import Spectrum1D
+from ..spectra.spectrum import Spectrum
 
 from astropy.tests.helper import assert_quantity_allclose
 
@@ -126,29 +125,21 @@ def test_create_from_spectral_axis(observer, target):
 def test_change_radial_velocity():
     wave = np.linspace(100, 200, 100) * u.AA
     flux = np.ones(100) * u.one
-    spec = Spectrum1D(spectral_axis=wave, flux=flux,
+    spec = Spectrum(spectral_axis=wave, flux=flux,
                       radial_velocity=0 * u.km / u.s)
 
     assert spec.radial_velocity == 0 * u.km/u.s
 
-    with pytest.warns(
-        AstropyDeprecationWarning,
-        match="Use set_radial_velocity_to or shift_spectrum_to instead"
-    ):
-        spec.radial_velocity = 1 * u.km / u.s
+    spec.set_radial_velocity_to(1 * u.km / u.s)
 
     assert spec.radial_velocity == 1 * u.km/u.s
 
-    spec = Spectrum1D(spectral_axis=wave, flux=flux,
+    spec = Spectrum(spectral_axis=wave, flux=flux,
                       radial_velocity=10 * u.km / u.s)
 
     assert spec.radial_velocity == 10 * u.km / u.s
 
-    with pytest.warns(
-        AstropyDeprecationWarning,
-        match="Use set_radial_velocity_to or shift_spectrum_to instead"
-    ):
-        spec.radial_velocity = 5 * u.km / u.s
+    spec.set_radial_velocity_to(5 * u.km / u.s)
 
     assert spec.radial_velocity == 5 * u.km / u.s
 
@@ -156,7 +147,7 @@ def test_change_radial_velocity():
 def test_no_change_radial_velocity():
     wave = np.linspace(100, 200, 100) * u.AA
     flux = np.ones(100) * u.one
-    spec = Spectrum1D(spectral_axis=wave, flux=flux,
+    spec = Spectrum(spectral_axis=wave, flux=flux,
                       radial_velocity=0 * u.km / u.s)
 
     assert spec.radial_velocity == 0 * u.km/u.s
@@ -168,33 +159,25 @@ def test_no_change_radial_velocity():
 def test_change_redshift():
     wave = np.linspace(100, 200, 100) * u.AA
     flux = np.ones(100) * u.one
-    spec = Spectrum1D(spectral_axis=wave, flux=flux, redshift=0)
+    spec = Spectrum(spectral_axis=wave, flux=flux, redshift=0)
 
     assert spec.redshift.unit.physical_type == 'dimensionless'
     assert_quantity_allclose(spec.redshift, u.Quantity(0))
     assert isinstance(spec.spectral_axis, SpectralAxis)
 
-    with pytest.warns(
-        AstropyDeprecationWarning,
-        match="Use set_redshift_to or shift_spectrum_to instead"
-    ):
-        spec.redshift = 0.1
+    spec.set_redshift_to(0.1)
 
     assert spec.redshift.unit.physical_type == 'dimensionless'
     assert_quantity_allclose(spec.redshift, u.Quantity(0.1))
     assert isinstance(spec.spectral_axis, SpectralAxis)
 
-    spec = Spectrum1D(spectral_axis=wave, flux=flux, redshift=0.2)
+    spec = Spectrum(spectral_axis=wave, flux=flux, redshift=0.2)
 
     assert spec.redshift.unit.physical_type == 'dimensionless'
     assert_quantity_allclose(spec.redshift, u.Quantity(0.2))
     assert isinstance(spec.spectral_axis, SpectralAxis)
 
-    with pytest.warns(
-        AstropyDeprecationWarning,
-        match="Use set_redshift_to or shift_spectrum_to instead"
-    ):
-        spec.redshift = 0.4
+    spec.set_redshift_to(0.4)
 
     assert spec.redshift.unit.physical_type == 'dimensionless'
     assert_quantity_allclose(spec.redshift, u.Quantity(0.4))
@@ -204,7 +187,7 @@ def test_change_redshift():
 def test_no_change_redshift():
     wave = np.linspace(100, 200, 100) * u.AA
     flux = np.ones(100) * u.one
-    spec = Spectrum1D(spectral_axis=wave, flux=flux, redshift=0)
+    spec = Spectrum(spectral_axis=wave, flux=flux, redshift=0)
 
     assert spec.redshift.unit.physical_type == 'dimensionless'
     assert_quantity_allclose(spec.redshift, u.Quantity(0))
@@ -228,5 +211,5 @@ def test_pixel_descending_error():
     spec_unit = u.pix
 
     with pytest.raises(ValueError, match="u.pix spectral axes should always be ascending"):
-        Spectrum1D(spectral_axis=(np.arange(5100, 5300)[::-1])*spec_unit,
+        Spectrum(spectral_axis=(np.arange(5100, 5300)[::-1])*spec_unit,
                 flux=np.random.randn(200)*flux_unit)
